# -*- coding: utf8 -*-
from __future__ import unicode_literals

from driverng.astm import HprimString
from driverng.drivers.epicenter_spec import Driver as Epicenter
from driverng.drivers.epicenter_spec import EpicenterSegmentP


class BactecFxSegmentP(EpicenterSegmentP):
    patient_id = HprimString((4, 1))
    last_name = HprimString((6, 1))
    first_name = HprimString((6, 2))
    location = HprimString((33, 1))


class Driver(Epicenter):
    SPEC = {"code": "bactec_fx", "label": "Bactec FX"}

    def encode_worklist(self, worklist, context):
        message = self.create(date=context["now"])
        for patient in worklist.get_astm_worklist(
            unique_together=["action"],
            action={"del": worklist.IGNORE, worklist.ELSE: None},
        ):
            for sample, action in patient.samples:
                seg_p = message.patients.add(
                    patient_id=patient.patient_id,
                    last_name=patient.last_name,
                    first_name=patient.first_name,
                    location=patient.location,
                )
                for order in sample.orders:
                    seg_p.orders.add(
                        accession_number=sample.sample_id,
                        test_id=order.code,
                        collection_date=sample.collection_date,
                    )
        if message.patients:
            return message
