# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "bn2_autohost"


def test_encode_order(self):
    message = self.order()
    expected = "J123456                       13052011F1001NYME                ANO                 036666666                     PRESCRIBER                  A1 B0"
    assert message == expected


def test_decode_query(self):
    _query_message = "J199043311283                 "
    worklist = self.decode(_query_message)
    expected = {
        "context": "query",
        "samples": [{"type": "patient", "sample_id": "199043311283"}],
    }
    assert worklist == expected


def test_decode_result(self):
    worklist = self.decode(
        "D199013301238                 89  15     1.5700E+01mg/l     0 0 0 0BNII 271114094320"
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "199013301238",
                "results": [
                    {
                        "code": "89",
                        "value": "1.5700E+01",
                        "flags": ["NOT_VALID", "TURBID", "SPECIAL_PREDILUTION"],
                        "date": datetime.datetime(2014, 11, 27, 9, 43, 20),
                    }
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_control(self):
    worklist = self.decode(
        "R4735                         89   0     1.2900E+01mg/l          3.2000E+0018BNII 271114090750"
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "control",
                "control_lot": "4735",
                "sample_id": "4735",
                "results": [
                    {
                        "code": "89",
                        "value": "12.9",
                        "flags": [],
                        "date": datetime.datetime(2014, 11, 27, 9, 7, 50),
                    }
                ],
            }
        ],
    }
    assert worklist == expected
