# -*- coding: utf8 -*-
from __future__ import unicode_literals

import copy
import datetime

parser_class = "engen"


def test_encode_order(self):
    worklist = copy.deepcopy(self.order_worklist)
    worklist.samples[0].orders.append(
        {"code": "D", "dilution": "", "action": "add", "priority": "S"}
    )
    message = self.order(worklist=worklist)
    expected = """
    H|\\^&||||||||||P|1|20130715141912
    P|1|036666666|||NYME^ANO||20110513|F|||||PRESCRIBER
    O|1|123456||^^^A^1:10|S||20130513114242||||N|||20130513114242|Serum
    O|2|123456||^^^B\\^^^D|S||20130513114242||||A|||20130513114242|Serum
    O|3|123456||^^^C|S||20130513114242||||C|||20130513114242|Serum
    L|1|N
    """
    assert message == expected


def test_decode_result(self):
    worklist = self.decode(
        """
    H|\\^&|||DI||||||v7.00.0001_dev01|P|1|20060419165104
    P|1|16611006||001-50-1234|SMITH^LUCILLE^J||19441123|F|C||||789^Daniels^Larry^B|||||||||PF2||F|Fac1^Ward 1^Rm 1^Bed1^NS2
    O|1|2352363|001^2^5|^^^GLU\\^^^BUN|R|||||||||200618120804|SER
    R|1|^^^GLU|23.845|mg/dL|1.0 to 5.0|Err1\\Err2\\Err3||F||OP1^||20141217171830|Inst 1
    C|1|I|Comment 1|G
    R|2|^^^BUN|100|%|1 to 100| ||V||OP1^||20141217171830|Inst 1
    C|1|I|Alarme|I
    R|3|^^^GUN|100|||||P||OP1^||20141217171830|Inst 1
    L|1|N
    """
    )
    date = datetime.datetime(2014, 12, 17, 17, 18, 30)
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "2352363",
                "rack": "2-5",
                "results": [
                    {
                        "code": "GLU",
                        "value": "23.845",
                        "flags": ["Err1", "Err2", "Err3"],
                        "date": date,
                        "comments": ["Comment 1"],
                        "instrument": "Inst 1",
                        "operator": "OP1",
                    },
                    {
                        "code": "BUN",
                        "value": "100",
                        "flags": ["Alarme"],
                        "date": date,
                        "comments": [],
                        "instrument": "Inst 1",
                        "operator": "OP1",
                    },
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_message(self):
    worklist = self.decode(
        """
    H|\\^&|||IM||||||v8.00.0002|P|1|20150609142945
    M|1|EQU|^ TCA IN^RD|20150609|OP|L|N
    M|2|SAC|||7060700540||||20150609142945|R|Carrier|*27794*|10^A
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [{"sample_id": "7060700540", "type": "patient"}],
    }
    assert worklist == expected


def test_decode_control(self):
    worklist = self.decode(
        """
    H|\\^&|||DI||||||v7.00.0001_dev01|P|1|20141217165104
    P|1
    O|1|QC-001|001^2^5|^^^GLU|R||||||Q|||20141217120804|SER
    R|1|^^^GLU|23.845|mg/dL|1.0 to 5.0|||F||OP1^||20141217170830|Inst 1
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "control",
                "control_lot": "QC-001",
                "sample_id": "QC-001",
                "rack": "2-5",
                "results": [
                    {
                        "code": "GLU",
                        "value": "23.845",
                        "flags": [],
                        "comments": [],
                        "date": datetime.datetime(2014, 12, 17, 17, 8, 30),
                        "instrument": "Inst 1",
                    }
                ],
            }
        ],
    }
    assert worklist == expected
