# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "genexpert"


def test_encode_order(self):
    message = self.order()
    expected = """
    H|@^&|20130715141912|||||||GeneXpert PC^GeneXpert^4.6||P|1394-97|20130715141912
    P|1|||036666666
    O|1|123456||^^^A|R|20130603110342|||||A||||Serum||||||||||Q
    O|2|123456||^^^B|R|20130603110342|||||A||||Serum||||||||||Q
    O|3|123456||^^^C|R|20130603110342|||||C||||Serum||||||||||Q
    L|1|N
    """
    assert message == expected


def test_decode_query(self):
    worklist = self.decode(
        """
    H|\\^&|b4a88d9adab947a7b3dca2b534119c25||ICU^GeneXpert^1.0|||||LIS||P|1394-97|20140521100245
    Q|1|556^123456||||||||||O
    L|1|N
    """
    )
    expected = {
        "context": "query",
        "samples": [{"type": "patient", "sample_id": "556"}],
    }
    assert worklist == expected


def test_decode_result(self):
    worklist = self.decode(
        """
    H|@^\\|URM-ODMJlrUA-08||GeneXpertPC^GeneXpert^4.6|||||NEO||P|1394-97|20150113131318
    P|1
    O|1|630013010380||^^^XHIV1|R|20141028154539|||||||||ORH|||^^|||||||F
    R|1|^^^XHIV1^HIV-1 Quant RUO^5^^|DETECTE^|copies/mL|40,00 to10000000,00|<||F||<Aucun>|20141028154539|20141028171600|Cepheid-3520VYQ^713169^648924^224678375^00501^20991220
    R|2|^^^XHIV1^HIV-1 Quant RUO^5^^LOG|^|copies/mL|1,60 to7,00|<||F||<Aucun>|20141028154539|20141028171600|Cepheid-3520VYQ^713169^648924^224678375^00501^20991220
    R|3|^^^XHIV1^^^HIV-1^|POS
    R|4|^^^XHIV1^^^HIV-1^Ct|^42,1
    R|5|^^^XHIV1^^^HIV-1^EndPt|^43,0
    R|6|^^^XHIV1^^^HIV-1^Delta Ct|^-12,9|||
    R|7|^^^XHIV1^^^IQS-H^|REUSSITE^|||
    R|8|^^^XHIV1^^^IQS-H^Ct|^24,5
    C|1|I|id1^code1^0.4 ml d'échantillon + 0.6 ml de contrôle neg|I
    C|2|I|^code2|I
    C|2|I|id3^|I
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "630013010380",
                "results": [
                    {
                        "code": "XHIV1HIV-1 Quant RUO5",
                        "comments": [],
                        "date": datetime.datetime(2014, 10, 28, 17, 16),
                        "flags": ["<"],
                        "value": "DETECTE",
                        "lots": [
                            {
                                "expiration": datetime.datetime(2099, 12, 20, 0, 0),
                                "lot": "00501",
                                "type": "reagent",
                            }
                        ],
                        "operator": "<Aucun>",
                    },
                    {
                        "code": "XHIV1HIV-1 Quant RUO5LOG",
                        "comments": [],
                        "date": datetime.datetime(2014, 10, 28, 17, 16),
                        "flags": ["<"],
                        "value": "",
                        "lots": [
                            {
                                "expiration": datetime.datetime(2099, 12, 20, 0, 0),
                                "lot": "00501",
                                "type": "reagent",
                            }
                        ],
                        "operator": "<Aucun>",
                    },
                    {
                        "code": "XHIV1HIV-1",
                        "comments": [],
                        "date": None,
                        "flags": [],
                        "value": "POS",
                    },
                    {
                        "code": "XHIV1HIV-1Ct",
                        "comments": [],
                        "date": None,
                        "flags": [],
                        "value": "42.1",
                    },
                    {
                        "code": "XHIV1HIV-1EndPt",
                        "comments": [],
                        "date": None,
                        "flags": [],
                        "value": "43.0",
                    },
                    {
                        "code": "XHIV1HIV-1Delta Ct",
                        "comments": [],
                        "date": None,
                        "flags": [],
                        "value": "-12.9",
                    },
                    {
                        "code": "XHIV1IQS-H",
                        "comments": [],
                        "date": None,
                        "flags": [],
                        "value": "REUSSITE",
                    },
                    {
                        "code": "XHIV1IQS-HCt",
                        "comments": [],
                        "date": None,
                        "flags": ["id1 code1", "code2", "id3"],
                        "value": "24.5",
                    },
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_control(self):
    worklist = self.decode(
        """
    H|@^\\|URM-RphmZDVA-01||GeneXpert PC^GeneXpert^4.6a|||||NEO||P|1394-97|20151105134246
    P|1||||^^^^
    O|1|10091596||^^^XHIV1|R|20151026170342|||||Q||||ORH|||^^|||||||F
    R|1|^^^XHIV1^Xpert HIV-1 Viral Load^1^^|^320,28|copies/mL|40,00 to 10000000,00|N||F||LAURE OTTOMANI|20151026170342|20151026183403|^713169
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "control",
                "control_lot": "10091596",
                "sample_id": "10091596",
                "results": [
                    {
                        "code": "XHIV1Xpert HIV-1 Viral Load1",
                        "comments": [],
                        "date": datetime.datetime(2015, 10, 26, 18, 34, 3),
                        "flags": ["N"],
                        "value": "320.28",
                    }
                ],
            }
        ],
    }
    assert worklist == expected
