# -*- coding: utf8 -*-

from __future__ import unicode_literals

import datetime

import driverng
from driverng.tests import unindent

parser_class = "immunocap"


def test_order(self):
    result = self.order()
    expected = """H|\\^&|||MCA|||||||P|1|20130715141912
        P|1|036666666|||NYME ANO|NJF|20110513|F
        O|1|123456||^^^A^Serum\\^^^B^Serum|||||||N||1||||||||||||O
        O|2|123456||^^^C^Serum|||||||C||1||||||||||||O
        L|1|F"""
    assert result == expected


def test_result(self):
    result = self.decode(
        """
    H|\\^&|||ImmunoCAP Data Manager (IDM)^5.43^4.0|||||^||P|1|20130610153450
    P|1|0443086029|||TEST ANONYME||19820511|M||^^^^||||^^^^|0||||||
    O|1|0443086029^N^0004^1|0443086029|^^^g6^sIgE^1||18991230000000|20130608000000||||N||1|||^^||^^^^^^0||||18991230000000||#1362|F||^^^^^
    R|1|^^^g6^sIgE^1|25.4^^Negatif^^|kUA/l||||F||||20130610143250|#1362
    C|1|O|Id Opérateur |I
    C|2|O|Valeur réponse en RU BAS|I
    L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "0443086029",
                "rack": "0004-1",
                "type": "patient",
                "results": [
                    {
                        "code": "g6",
                        "value": "25.4",
                        "flags": ["RUBAS"],
                        "comments": ["Id Opérateur", "Valeur réponse en RU BAS"],
                        "operator": "",
                        "date": datetime.datetime(2013, 6, 10, 14, 32, 50),
                        "instrument": "",
                        "lots": [],
                        "operator": "",
                    },
                    {
                        "code": "g6CUT1",
                        "value": "Negatif",
                        "flags": ["RUBAS"],
                        "comments": ["Id Opérateur", "Valeur réponse en RU BAS"],
                        "date": datetime.datetime(2013, 6, 10, 14, 32, 50),
                        "operator": "",
                        "instrument": "",
                        "lots": [],
                        "operator": "",
                    },
                ],
            }
        ],
    }
    assert result == expected


def test_result_idm(self):
    self.configure(idm_version=True)
    result = self.decode(
        """
    H|\\^&|||Phadia.Prime^1.2.0.12371^4.0|||||^127.0.0.1||P|1|20120522132718
    P|1||||||18991230|||^^^^||||^^^^|0||||||
    O|1|B7650020^N^^0|B7650020|^^^t2^sIgE^1||18991230000000|20030503000000||||N||1|||^^||^^^^^^0||||18991230000000||I1000-1|F||^^^^
    R|1|^^^t2^sIgE^1|9.34^^^^^^^|kUA/l||||F||||20170503124704|I1000-1
    L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "B7650020",
                "type": "patient",
                "rack": None,
                "results": [
                    {
                        "code": "t2",
                        "value": "9.34",
                        "flags": [],
                        "date": datetime.datetime(2017, 5, 3, 12, 47, 4),
                        "comments": [],
                        "lots": [],
                        "operator": "",
                        "instrument": "I1000-1",
                    }
                ],
            }
        ],
    }
    assert result == expected


def test_enregistrer_queryall(self):
    result = self.parser.enregistrer(
        unindent(
            """
        H|\\^&|||ImmunoCAP^5.45^4.0|||||^||P|1|20130924152052
        Q|1|^ALL||||||||||O
        L|1|N"""
        )
    )
    assert result is False


def test_query(self):
    result = self.decode(
        """
    H|\\^&|||ImmunoCAP^5.45^4.0|||||^||P|1|20130924152052
    Q|1|^123456789||||||||||O
    L|1|N"""
    )
    expected = {
        "context": "query",
        "samples": [{"sample_id": "123456789", "type": "patient"}],
    }
    assert result == expected


def test_void_order(self):
    result = self.order(
        worklist=driverng.Worklist(context="order"),
        context={
            "query": self.parse(
                """
    H|\\^&|||ImmunoCAP^5.45^4.0|||||^||P|1|20130924152052
    Q|1|^123456789||||||||||O
    L|1|N"""
            )
        },
    )
    expected = """
    H|\\^&|||MCA|||||||P|1|20130715141912
    L|1|F"""
    assert result == expected


def test_qc(self):
    result = self.decode(
        """
    H|\\^&|||ImmunoCAP Data Manager (IDM)^5.45^4.0|||||^||Q|1|20140418154438
    P|1||||||18991230|||^^^^||||^^^^|0
    O|1|^N^^0|EliA Neg|^^^Mrf^El-M^1||18991230000000|20140418132956||||Q||100|||^^||^^^^^^0||||18991230000000||#2307|F
    R|1|^^^Mrf^El-M^1|<0.4^^^|IU/ml||||M||||20140418132956|#2307
    L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "EliA Neg",
                "control_lot": "EliA Neg",
                "type": "control",
                "results": [
                    {
                        "comments": [],
                        "date": datetime.datetime(2014, 4, 18, 13, 29, 56),
                        "value": "<0.4",
                        "flags": [],
                        "code": "Mrf",
                        "instrument": "#2307",
                        "lots": [],
                        "operator": "",
                    }
                ],
            }
        ],
    }
    assert result == expected


def test_qc_with_refence_in_comment(self):
    result = self.decode(
        """
    H|\\^&|||Phadia.Prime^2.2.4.18^4.0|||||^127.0.0.1||Q|1|20180717105556
    P|1|||||||||^^^^||||^^^^|||||||
    O|1|^N^^|sIgE L|^^^e1^1^1|||20180717094315||||Q||1|||^^||^^^^^^0||||20180717105556||Ic250|F||^^^^^
    R|1|^^^e1^1^1|2.65^^^|kUA/l||||M||||20180717094315|Ic250
    C|1|O|ImmunoCAP 359EB|I
    C|2|O|Conjugué A1HG6|I
    C|3|O|Flacon Contrôle Qualité CZ4AH|I
    L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "CZ4AH",
                "control_lot": "CZ4AH",
                "type": "control",
                "results": [
                    {
                        "date": datetime.datetime(2018, 7, 17, 9, 43, 15),
                        "flags": [],
                        "value": "2.65",
                        "code": "e1",
                        "instrument": "Ic250",
                        "comments": [],
                        "lots": [],
                        "operator": "",
                    }
                ],
            }
        ],
    }
    assert result == expected
