# -*- coding: utf8 -*-
from __future__ import unicode_literals

import copy

parser_class = "kibion_dynamic"


def test_encode_order(self):
    self.configure(kibion_dynamic_sender_name="IRIS4")

    worklist = copy.deepcopy(self.order_worklist)
    worklist.samples[0].orders = ({"code": "HP", "action": "new", "priority": "A"},)
    message = self.order(worklist=worklist)
    expected = """
        H|\\^&|||IRIS4
        P|1|036666666|||NYME^ANO||20110513|F||||||||170|58
        O|1|123456||^^^HP
        L|1
    """
    assert message == expected


def test_encode_empty_height(self):
    self.configure(kibion_dynamic_sender_name="IRIS4")

    worklist = copy.deepcopy(self.order_worklist)
    worklist.samples[0].orders = ({"code": "HP", "action": "new", "priority": "A"},)
    worklist.samples[0]["height"] = ""
    message = self.order(worklist=worklist)
    expected = """
        H|\\^&|||IRIS4
        P|1|036666666|||NYME^ANO||20110513|F|||||||||58
        O|1|123456||^^^HP
        L|1
    """
    assert message == expected


def test_decode_query(self):
    worklist = self.decode(
        """
        H|\\^&|||IRIS4|||||
        Q|1|1234^5678^^|^^^|^^^||||||||O
        L|1|N
    """
    )
    expected = {
        "context": "query",
        "samples": [{"type": "patient", "sample_id": "5678"}],
    }
    assert worklist == expected


def test_decode_result(self):
    worklist = self.decode(
        """
        H|\\^&|||IRIS4|||||
        P|1|/J1O0NdkhkSoyNXWKy1k1Q|||MUSTERMANN^MAX^||19800101|M||||||||175|75|||||||||||||||||
        O|1|5678^0||^^^HP||20151003|||||||||^||||||||||Positive||||||
        R|1|^^^HP|^3.60435080528259^^|%||||F|||||
        R|2|^^^HP|^359.738037109375^^|ppm||||F|||||
        R|3|^^^HP|^0^^|%13C||||F|||||
        R|4|^^^HP|^-26.9202575683594^^|0/00||||F|||||
        R|5|^^^HP|^0^^|0/00||||F|||||
        R|6|^^^HP|^0^^|%13C||||F|||||
        O|2|5678^10||^^^HP||20151003|||||||||^||||||||||
        R|1|^^^HP|^3.90875911712646^^|%||||F|||||
        R|2|^^^HP|^388.832275390625^^|ppm||||F|||||
        R|3|^^^HP|^0^^|%13C||||F|||||
        R|4|^^^HP|^-27.7532272338867^^|0/00||||F|||||
        R|5|^^^HP|^-0.832969665527344^^|0/00||||F|||||
        R|6|^^^HP|^0^^|%13C||||F|||||
        L|1F
    """
    )

    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "5678",
                "results": [
                    {"code": "HP-12CO2-0", "value": "3.60435080528259", "unit": "%"},
                    {"code": "HP-13CO2-0", "value": "359.738037109375", "unit": "ppm"},
                    {"code": "HP-Cum.dose-0", "value": "0", "unit": "%13C"},
                    {
                        "code": "HP-Delta-0",
                        "value": "-26.9202575683594",
                        "unit": "0/00",
                    },
                    {"code": "HP-DOB-0", "value": "0", "unit": "0/00"},
                    {"code": "HP-Dose/h-0", "value": "0", "unit": "%13C"},
                    {"code": "HP-12CO2-10", "value": "3.90875911712646", "unit": "%"},
                    {"code": "HP-13CO2-10", "value": "388.832275390625", "unit": "ppm"},
                    {"code": "HP-Cum.dose-10", "value": "0", "unit": "%13C"},
                    {
                        "code": "HP-Delta-10",
                        "value": "-27.7532272338867",
                        "unit": "0/00",
                    },
                    {
                        "code": "HP-DOB-10",
                        "value": "-0.832969665527344",
                        "unit": "0/00",
                    },
                    {"code": "HP-Dose/h-10", "value": "0", "unit": "%13C"},
                ],
            }
        ],
    }
    assert worklist == expected
