# -*- coding: utf8 -*-
from __future__ import unicode_literals

import copy
import datetime

import pytest

parser_class = "scanlab"


def test_encode_order(self):
    message = self.order()
    expected = """
    H|^~\\&||||||||||P||20130715141912
    P|1|036666666|||NYME^ANO|NJF|20110513|F|||||||||||||||||LOC
    OBR|1|^123456||A~B|||20130513114242||||||||Serum
    L|1|N"""
    assert message == expected


def test_encode_order_with_transcode_rack_dms_tracking_serotheque(self):
    self.configure(scanlab_transcodage_rack_dms_tracking=True)
    worklist = copy.deepcopy(self.order_worklist)
    worklist.samples[0].rack_dms_tracking_serotheque = "IOM-000041-03-09-15"
    worklist.samples[0].sequence_scanlab = "25"
    message = self.order(worklist=worklist)
    expected = """
    H|^~\\&||||||||||P||20130715141912
    P|1|036666666|||NYME^ANO|NJF|20110513|F|||||||||||||||||LOC
    OBR|1|^123456||A~B|P48/00025;39||20130513114242||||||||Serum
    L|1|N"""
    assert message == expected


def test_encode_order_without_trancode_rack_dms_tracking_serotheque(self):
    self.configure(scanlab_transcodage_rack_dms_tracking=True)
    worklist = copy.deepcopy(self.order_worklist)
    worklist.samples[0].rack_dms_tracking_serotheque = "000041-03-09-AA"
    worklist.samples[0].sequence_scanlab = "25"
    message = self.order(worklist=worklist)
    expected = """
    H|^~\\&||||||||||P||20130715141912
    P|1|036666666|||NYME^ANO|NJF|20110513|F|||||||||||||||||LOC
    OBR|1|^123456||A~B|||20130513114242||||||||Serum
    L|1|N"""
    assert message == expected


def test_encode_order_with_serotheque(self):
    self.configure(scanlab_envoyer_no_serotheque=True)
    worklist = copy.deepcopy(self.order_worklist)
    worklist.samples[0].info_serotheque.codes = "SERO"
    worklist.samples[0].info_serotheque.portoir = "T0001"
    worklist.samples[0].info_serotheque.sample_id = "12346"
    worklist.samples[0].info_serotheque.destination = "PLATEAU"
    worklist.samples[0].info_serotheque.numero = "101"
    worklist.samples[0].info_serotheque.position = "1,1"
    worklist.samples[0].info_serotheque.etiquette = "T001 A,1"

    message = self.order(worklist=worklist)
    expected = """
    H|^~\\&||||||||||P||20130715141912
    P|1|036666666|||NYME^ANO|NJF|20110513|F|||||||||||||||||LOC
    OBR|1|^123456||A~B|T0001/101;1,1||20130513114242||||||||Serum
    L|1|N"""
    assert message == expected


@pytest.mark.parametrize(
    "message",
    [
        """
    H|^~\\&|||TDR||ORU|||LIS||P|H1.2|20141025090338
    P|1|00922711478|||TEST^Anonyme||19900926|F
    OBR|1|17190119419^||SER|R||||||||||SER|
    OBX|1|TX|SER||41017190119419|||N||||Congelat.:C04;Rayon:R12;Portoir:01176;Repere:23;|20141025090305
    L|1|F
    """,
        """
    H|^~\\&|||TDR||ORU|||LIS||P|H1.2|20141025090338
    P|1|00922711478|||TEST^Anonyme||19900926|F
    OBR|1|ZZZ^17190119419||SER|R||||||||||SER|
    OBX|1|TX|SER||41017190119419|||N||||Congelat.:C04;Rayon:R12;Portoir:01176;Repere:23;|20141025090305
    L|1|F
    """,
        """
    H|^~\\&|||TDR||ORU|||LIS||P|H1.2|20141025090338
    P|1|00922711478|||TEST^Anonyme||19900926|F
    OBR|1|^17190119419||SER|R||||||||||SER|
    OBX|1|TX|SER||41017190119419|||N||||Congelat.:C04;Rayon:R12;Portoir:01176;Repere:23;|20141025090305
    L|1|F
    """,
    ],
)
def test_decode_result(self, message):
    worklist = self.decode(message)
    expected = {
        "context": "result",
        "samples": [
            {
                "sample_id": "17190119419",
                "type": "patient",
                "results": [
                    {
                        "code": "SER",
                        "date": datetime.datetime(2014, 10, 25, 9, 3, 5),
                        "value": "Congelat.:C04;Rayon:R12;Portoir:01176;Repere:23;",
                    }
                ],
            }
        ],
    }
    assert worklist == expected
