# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "starexp_astm"


def test_encode_order(self):
    message = self.order()
    expected = """
    H|\\^&|||99|||||||P|LIS2-A2|20130715141912
    P|1|036666666|||NYME^ANO|NJF|20110513|F|||||PRESCRIBER^Prescriber|||1.70|58||MEDOC1;MEDOC2||Commentaire patient no1||||^^SER
    O|1|123456||^^^A\\^^^B|R||20130603110342||||N|||||PRESCRIBER^Prescriber^^SER
    R|1|^^^A|42|||||N||||20110506121400
    R|2|^^^B|201302131516|||||N||||20110506121300
    O|2|123456||^^^C|R||20130603110342||||C|||||PRESCRIBER^Prescriber^^SER
    L|1|N
    """
    assert message == expected


def test_query(self):
    worklist = self.decode(
        """
    H|\\^&|||99|||||||P|LIS2-A2|20180214111611
    Q|1|^1980450006TV
    L|1|N
    """
    )
    expected = {
        "context": "query",
        "samples": [{"type": "patient", "sample_id": "1980450006TV"}],
    }
    assert worklist == expected


def test_decode_result(self):
    worklist = self.decode(
        """
        H|\\^&|||99|||||||P|1|201410151610
        P|1|100||^^^|PAT-100||19650501|F|||||DcJ^Doctor JONES||||||||||||
        O|7|03104^288094^1^||^^^8^PTTAAUTOrf|R||||||||||||||||||||F
        R|1|^^^111401^^^^F|A|||||F||||20141015121000
        R|1|^^^8^PTTAAUTOrf^^F|18.8|Sec||A||F||CxAutomate||20150403165841|RMAX
        C|1|I|To Review^Suspicion of inhibitor (LA or anti-factor) : Run FVIII-IX-XI
        M|1|A|C\\H||12203^STA-PTT A^110368|||11851^CaCl2 0.025 M^999||S45113|CLEANER^STA-CLEANER^999999|||||7
        L|1|N
        """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "03104",
                "rack": "288094-1",
                "results": [
                    {
                        "value": "A",
                        "code": "111401",
                        "date": datetime.datetime(2014, 10, 15, 12, 10, 00),
                        "flags": [],
                        "instrument": "",
                        "comments": [],
                    },
                    {
                        "value": "18.8",
                        "code": "8",
                        "date": datetime.datetime(2015, 4, 3, 16, 58, 41),
                        "instrument": "RMAX",
                        "flags": ["C", "H"],
                        "operator": "CxAutomate",
                        "comments": [
                            "To Review",
                            "Suspicion of inhibitor (LA or anti-factor) : Run FVIII-IX-XI",
                        ],
                        "lots": [
                            {"type": "reagent", "lot": "110368", "name": "STA-PTT A"},
                            {"type": "reagent", "lot": "999", "name": "CaCl2 0.025 M"},
                        ],
                    },
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_rack_vide(self):
    worklist = self.decode(
        """
        H|\\^&|||99|||||||P|1|201410151610
        P|1|100||^^^|PAT-100||19650501|F|||||DcJ^Doctor JONES||||||||||||
        O|7|03104^^^||^^^8^PTTAAUTOrf|R||||||||||||||||||||F
        R|1|^^^111401^^^^F|A|||||F||||20141015121000
        L|1|N
        """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "03104",
                "results": [
                    {
                        "value": "A",
                        "code": "111401",
                        "date": datetime.datetime(2014, 10, 15, 12, 10, 00),
                        "flags": [],
                        "instrument": "",
                        "comments": [],
                    }
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_control(self):
    worklist = self.decode(
        """
        H|\\^&|||LIS |||||||Q|1|201410151610
        P|1|100||^^^|PAT-100||19650501|F|||||DcJ^Doctor JONES||||||||||||
        O|7|SampleQC^288094^1^NoLotQc||^^^8^PTTAAUTOrf|R||||||||||||||||||||F
        R|1|^^^8^PTTAAUTOrf^^F|18.8|Sec||A||F||CxAutomate||20150403165841|RMAX
        L|1|N
        """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "control",
                "control_lot": "SampleQCNoLotQc",
                "sample_id": "SampleQC",
                "rack": "288094-1",
                "results": [
                    {
                        "value": "18.8",
                        "code": "8",
                        "date": datetime.datetime(2015, 4, 3, 16, 58, 41),
                        "instrument": "RMAX",
                        "flags": [],
                        "comments": [],
                    }
                ],
            }
        ],
    }

    assert worklist == expected
