# -*- coding: utf8 -*-

from __future__ import unicode_literals

parser_class = "virclia"


def test_query(self):
    worklist = self.decode(
        """
    H|\\^&|||VIRCLA|||||||P|LIS2-A2|20140213111038
    Q|1|S001^||ALL
    Q|2|S002^||ALL
    L|1|F"""
    )
    expected = {
        "context": "query",
        "samples": [
            {"type": "patient", "sample_id": "S001"},
            {"type": "patient", "sample_id": "S002"},
        ],
    }
    assert worklist == expected


def test_void_order(self):
    message = self.order(
        worklist=self.void_worklist,
        context={
            "query": self.parse(
                """
            H|\\^&|||VIRCLA||||||||P|20140213111038
            Q|1|S001^||ALL
            Q|2|S002^||ALL
            L|1|N"""
            )
        },
    )
    expected = """
    H|\\^&||||||||||P|LIS2-A2|20130715141912
    P|1|S001
    P|2|S002
    L|1|N"""
    assert message == expected


def test_order(self):
    message = self.order()
    expected = """H|\\^&||||||||||P|LIS2-A2|20130715141912
        P|1|036666666|||NYME^ANO||20110513|F
        O|1|123456||^^^A|R
        O|2|123456||^^^B|R
        L|1|N"""
    assert message == expected


def test_result(self):
    worklist = self.decode(
        """
    H|\\^&|||Thunderbolt EIA^0.42.0.73|||||||P|LIS2-A2|20101022162157
    P|1||S001
    O|1|S001||^^^CMVIgG|R
    R|1|^^^CMVIgG^ST1|1.33|ng/ml||||F
    R|2|^^^CMVIgG^ST2|1.24|ng/ml||||F
    R|1|^^^HPLIgG|1.25^Positive|ng/ml||||F
    L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "S001",
                "results": [
                    {"code": "CMVIgG_ST1", "value": "1.33", "unit": "ng/ml"},
                    {"code": "CMVIgG_ST2", "value": "1.24", "unit": "ng/ml"},
                    {"code": "HPLIgG", "value": "1.25", "unit": "ng/ml"},
                    {"code": "HPLIgGI", "value": "Positive"},
                ],
            }
        ],
    }
    assert worklist == expected
