# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

from driverng.tests import BaseTest
from driverng.worklist import Worklist


class TestVitrosKermit(BaseTest):
    MAPPING_CLASS = "vitros_kermit"

    def test_result(self):
        date = datetime.datetime(datetime.datetime.now().year, 9, 30, 10, 57, 16)
        self.assertResultEqual(
            """
        1057160930               2673703832     10"41.000     6.36 100}!   76.   100}$    5.82 100}%    8.15 100}+    1.24 100}.   78.4  100}2    2.36 100}4   32.   000}5  102.   000}6   24.   000}:   54.   000}L    0.   053OR}Y    1.04 100}|J6911     ]""",
            {
                "2673703832": {
                    "resultats": [
                        {"date": date, "resu": "6.36", "test": "32"},
                        {"date": date, "resu": "76.", "test": "33"},
                        {"date": date, "resu": "5.82", "test": "36"},
                        {"date": date, "resu": "8.15", "test": "37"},
                        {"date": date, "resu": "1.24", "test": "43"},
                        {"date": date, "resu": "78.4", "test": "46"},
                        {"date": date, "resu": "2.36", "test": "50"},
                        {"date": date, "resu": "32.", "test": "52"},
                        {"date": date, "resu": "102.", "test": "53"},
                        {"date": date, "resu": "24.", "test": "54"},
                        {"date": date, "resu": "54.", "test": "58"},
                        {
                            "alarmes": ["5", "OR"],
                            "date": date,
                            "resu": "<0.",
                            "test": "76",
                        },
                        {"date": date, "resu": "1.04", "test": "89"},
                    ]
                }
            },
        )

    def test_order(self):
        self.assertOrderMessageEqual(
            Worklist(
                context="order",
                samples=[
                    {
                        "sample_id": "2673703832",
                        "type": "patient",
                        "last_name": "BOUVIER",
                        "first_name": "Marjorie",
                        "specimen": "1",
                        "orders": [
                            {"code": "33", "action": "add"},
                            {"code": "43", "action": "new"},
                            {"code": "37", "action": "del"},
                        ],
                    }
                ],
            ),
            """2673703832     10 01.00!+|BOUVIER        Marjorie  ]""",
        )
