# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "yhlo"


def test_encode_order(self):
    message = self.order()
    expected = """
    H|\\^&||||||||||SA|1394-97|20130715141912
    P|1||036666666|ADM_CLI|NYME^ANO||20110513^1^Y|F|||||ATTENDING|||||||||||||Information clinique
    O|1||123456|A^^1:10^^0\\B^^1^^1|S|20130603110342|20130513114242||||||||Serum|PRESCRIBER|||||||||O
    L|1
    """
    assert message == expected


def test_decode_query(self):
    worklist = self.decode(
        """
    H|\\^&|||iFlash3000^01.00.00.00^123456|||||||RQ|1394-97|20180101235959<CR>
    Q|1|^SAMPLE123||||||||||O<CR>
    L|1|N
    """
    )
    expected = {
        "context": "query",
        "samples": [{"type": "patient", "sample_id": "SAMPLE123"}],
    }
    assert worklist == expected


def test_decode_control(self):
    worklist = self.decode(
        """
    H|\\^&|||iFlash3000^01.00.00.00^123456|||||||QR|1394-97|20180101235959
    P|1|||||||||||||||||||||||||||||||||
    O|1|||COVM^CoV-2 IgM||20180101235959|||||1^QC1^1111^20100910^10^L^5^10.28\\2^QC2^2222^20100910^20^M^10^20.48\\3^QC3^3333^20100910^30^H^15^30.25||||||||||||||F|||||
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "control_lot": "1111",
                "control_name": "1111",
                "specimen": "",
                "sample_id": "1111",
                "type": "control",
                "results": [
                    {
                        "code": "COVM",
                        "date": datetime.datetime(2018, 1, 1, 23, 59, 59),
                        "value": "10.28",
                    }
                ],
            },
            {
                "control_lot": "2222",
                "control_name": "2222",
                "specimen": "",
                "sample_id": "2222",
                "type": "control",
                "results": [
                    {
                        "code": "COVM",
                        "date": datetime.datetime(2018, 1, 1, 23, 59, 59),
                        "value": "20.48",
                    }
                ],
            },
            {
                "control_lot": "3333",
                "control_name": "3333",
                "specimen": "",
                "sample_id": "3333",
                "type": "control",
                "results": [
                    {
                        "code": "COVM",
                        "date": datetime.datetime(2018, 1, 1, 23, 59, 59),
                        "value": "30.25",
                    }
                ],
            },
        ],
    }
    assert worklist == expected


def test_decode_result(self):
    date = datetime.datetime(2017, 10, 19, 11, 40, 59)
    worklist = self.decode(
        """
    H|\\^&|||^^||||||ASCII|PR|1394-97|20180120110408
    P|1||MedicalRecordSN1|HosNo1|zhangsan||19800101^0^Y|F|Nation1|Address1|B|TelNo1|||SecuritySN1||||PatientType1||||||Area1|BedNo1||||||||
    O|1|1^1&S&1|BarCode1|TP^TP^1.000000^^0\\UREA^UREA^1.000000^^0\\ALT^ALT^1.000000^^0|R|20170101000000|20180120105109||1.0|||||20180120105109|SampleType1|RequestDoctor1|RequestDept1|1.000000|||||||F|||||
    R|1|TP^TP1I|^+|ResultUnit1|||+|F||||20171019114059|
    R|2|UREA^UREA1B|3.23^+-|ResultUnit2|6.560000^|L|+-|F||||20171019114059|
    R|3|ALT^ALT1F|4.23^|ResultUnit3|7.560000^10.890000|H||F||||20171019114059|
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "rack": "1^1",
                "results": [
                    {
                        "code": "TP1I",
                        "comments": [],
                        "date": date,
                        "flags": [],
                        "instrument": "",
                        "operator": "",
                        "unit": "ResultUnit1",
                        "value": "+",
                    },
                    {
                        "code": "UREA",
                        "comments": [],
                        "date": date,
                        "flags": ["L"],
                        "instrument": "",
                        "operator": "",
                        "unit": "ResultUnit2",
                        "value": "3.23",
                    },
                    {
                        "code": "UREA1B",
                        "comments": [],
                        "date": date,
                        "flags": ["L"],
                        "instrument": "",
                        "operator": "",
                        "unit": "ResultUnit2",
                        "value": "+-",
                    },
                    {
                        "code": "ALT",
                        "comments": [],
                        "date": date,
                        "flags": ["H"],
                        "instrument": "",
                        "operator": "",
                        "unit": "ResultUnit3",
                        "value": "4.23",
                    },
                ],
                "sample_id": "BarCode1",
                "specimen": "SampleType1",
                "type": "patient",
            }
        ],
    }
    assert worklist == expected
